<?php
/**
 * The file is responsible for rendering the locations tab on the online maps settings page.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\Admin\SettingsPage\OnlineMaps\Locations;

use Locr\WordPress\Plugin\LocrMaps\Admin\OnlineMapLocationsTable;
use Locr\WordPress\Plugin\LocrMaps\DDD\ValueObjects\OnlineMap\Id as OnlineMapId;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for rendering the main online maps settings page.
 */
final class Main {
	/**
	 * This function renders the locations tab.
	 *
	 * @param OnlineMapId $onlinemap_id The online map ID.
	 */
	public static function process_and_render_locations_form( OnlineMapId $onlinemap_id ): void {
		$table = new OnlineMapLocationsTable( $onlinemap_id );

		$table->handle_table_actions( $onlinemap_id );

		$table->display_location_overlay_button();
		$table->display_location_overlay();

		print '<form method="post">';
		print '<input type="hidden" class="regular-text" id="onlinemap_id" name="onlinemap_id" readonly="readonly" value="' . esc_attr( (string) $onlinemap_id->value ) . '"/>';

		settings_errors();

		$table->prepare_items();
		$table->display();
		print '</form>';
	}
}
