<?php
/**
 * This is the entrypoint for the locrMAPS WordPress plugin.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\DDD\ValueObjects\OnlineMap\Location\Address;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for the street of the location address.
 *
 * @property-read string $value The raw value.
 */
final class Street implements \Stringable {
	/**
	 * The street value of the address.
	 *
	 * @var string
	 */
	private readonly string $value;

	/**
	 * The constructor.
	 *
	 * @param mixed $street The id of the location.
	 * @throws \InvalidArgumentException If the id is not numeric or less than 1.
	 */
	public function __construct( mixed $street = '' ) {
		if ( ! is_string( $street ) ) {
			throw new \InvalidArgumentException( 'The street must be a string.' );
		}

		$this->value = trim( $street );
	}

	/**
	 * The magick getter.
	 *
	 * @param string $name The name of the property.
	 * @throws \InvalidArgumentException If the property does not exist.
	 */
	public function __get( string $name ): mixed {
		return match ( $name ) {
			'value' => $this->value,
			default => throw new \InvalidArgumentException( 'The property "' . esc_html( $name ) . '" does not exist.' ),
		};
	}

	/**
	 * The magick to string method.
	 */
	public function __toString(): string {
		return $this->value;
	}
}
